@@ -371,7 +371,7 @@ static int hawki_twilight_flat_combine_create(cpl_plugin *plugin) {
     if (cpl_plugin_get_type(plugin) == CPL_PLUGIN_TYPE_RECIPE)
         recipe = (cpl_recipe *)plugin;
     else 
-        return(-1);
+        return(CPL_ERROR_UNSPECIFIED);
 
     /* Create the parameters list in the cpl_recipe object */
 
@@ -479,7 +479,7 @@ static int hawki_twilight_flat_combine_exec(cpl_plugin *plugin) {
     if (cpl_plugin_get_type(plugin) == CPL_PLUGIN_TYPE_RECIPE)
         recipe = (cpl_recipe *)plugin;
     else 
-        return(-1);
+        return(CPL_ERROR_UNSPECIFIED);
 
     return(hawki_twilight_flat_combine(recipe->parameters,recipe->frames));
 }
@@ -500,7 +500,7 @@ static int hawki_twilight_flat_combine_destroy(cpl_plugin *plugin) {
     if (cpl_plugin_get_type(plugin) == CPL_PLUGIN_TYPE_RECIPE)
         recipe = (cpl_recipe *)plugin;
     else 
-        return(-1);
+        return(CPL_ERROR_UNSPECIFIED);
 
     cpl_parameterlist_delete(recipe->parameters);
     return(0);
@@ -538,7 +538,7 @@ static int hawki_twilight_flat_combine(cpl_parameterlist *parlist,
 
     if (framelist == NULL || cpl_frameset_get_size(framelist) <= 0) {
         cpl_msg_error(fctid,"Input framelist NULL or has no input data");
-        return(-1);
+        return(CPL_ERROR_UNSPECIFIED);
     }
 
     /* Initialise some things */
@@ -584,7 +584,7 @@ static int hawki_twilight_flat_combine(cpl_parameterlist *parlist,
     if (hawki_dfs_set_groups(framelist) != CASU_OK) {
         cpl_msg_error(fctid,"Cannot identify RAW and CALIB frames");
         hawki_twilight_flat_combine_tidy(&ps,0);
-        return(-1);
+        return(CPL_ERROR_UNSPECIFIED);
     }
 
     /* Get the twilight frames */
@@ -593,13 +593,13 @@ static int hawki_twilight_flat_combine(cpl_parameterlist *parlist,
                                            &nlab)) == NULL) {
         cpl_msg_error(fctid,"Cannot labelise the input frames");
         hawki_twilight_flat_combine_tidy(&ps,0);
-        return(-1);
+        return(CPL_ERROR_UNSPECIFIED);
     }
     if ((ps.twilightlist = casu_frameset_subgroup(framelist,ps.labels,nlab,
                                                   HAWKI_TWI_RAW)) == NULL) {
         cpl_msg_error(fctid,"Cannot find twilight frames in input frameset");
         hawki_twilight_flat_combine_tidy(&ps,0);
-        return(-1);
+        return(CPL_ERROR_UNSPECIFIED);
     }
     ps.ntwilights = cpl_frameset_get_size(ps.twilightlist);
 
@@ -609,7 +609,7 @@ static int hawki_twilight_flat_combine(cpl_parameterlist *parlist,
                                                    HAWKI_CAL_DARK)) == NULL) {
         cpl_msg_error(fctid,"No master dark found");
         hawki_twilight_flat_combine_tidy(&ps,0);
-        return(-1);
+        return(CPL_ERROR_UNSPECIFIED);
     }
         
     /* Check to see if there is a reference twilight flat frame */
@@ -633,7 +633,7 @@ static int hawki_twilight_flat_combine(cpl_parameterlist *parlist,
 
     if (hawki_twilight_flat_cull(&(ps.twilightlist),&cs) != 0) {
         hawki_twilight_flat_combine_tidy(&ps,0);
-        return(-1);
+        return(CPL_ERROR_UNSPECIFIED);
     }
     ps.ntwilights = cpl_frameset_get_size(ps.twilightlist);
 
@@ -644,7 +644,7 @@ static int hawki_twilight_flat_combine(cpl_parameterlist *parlist,
         cpl_msg_error(fctid,"No value for NDIT available");
         freepropertylist(pp);
         hawki_twilight_flat_combine_tidy(&ps,0);
-        return(-1);
+        return(CPL_ERROR_UNSPECIFIED);
     }
     cpl_propertylist_delete(pp);
 
@@ -675,7 +675,7 @@ static int hawki_twilight_flat_combine(cpl_parameterlist *parlist,
                                                          &product_frame_bpm);
                                                          
             if (retval != 0)
-                return(-1);
+                return(CPL_ERROR_UNSPECIFIED);
             continue;
         }
 
@@ -708,7 +708,7 @@ static int hawki_twilight_flat_combine(cpl_parameterlist *parlist,
                                                          &product_frame_ratioimg_stats,
                                                          &product_frame_bpm);
             if (retval != 0)
-                return(-1);
+                return(CPL_ERROR_UNSPECIFIED);
             continue;
         }
 
@@ -795,7 +795,7 @@ static int hawki_twilight_flat_combine(cpl_parameterlist *parlist,
                                                          &product_frame_bpm);
 
             if (retval != 0)
-                return(-1);
+                return(CPL_ERROR_UNSPECIFIED);
             continue;
         } else if (casu_is_dummy(casu_fits_get_ehu(ps.mdark))) {
             cpl_msg_info(fctid,
@@ -809,7 +809,7 @@ static int hawki_twilight_flat_combine(cpl_parameterlist *parlist,
                                                          &product_frame_ratioimg_stats,
                                                          &product_frame_bpm);
             if (retval != 0)
-                return(-1);
+                return(CPL_ERROR_UNSPECIFIED);
             continue;
         }
 
@@ -849,7 +849,7 @@ static int hawki_twilight_flat_combine(cpl_parameterlist *parlist,
                                                      &product_frame_ratioimg_stats,
                                                      &product_frame_bpm);
         if (retval != 0)
-            return(-1);
+            return(CPL_ERROR_UNSPECIFIED);
 
     }
     hawki_twilight_flat_combine_tidy(&ps,0);
@@ -973,7 +973,7 @@ static int hawki_twilight_flat_combine_save(cpl_frameset *framelist,
                            CPL_IO_DEFAULT) != CPL_ERROR_NONE) {
             cpl_msg_error(fctid,"Cannot save product PHU");
             cpl_frame_delete(*product_frame_mean_twi);
-            return(-1);
+            return(CPL_ERROR_UNSPECIFIED);
         }
         cpl_frameset_insert(framelist,*product_frame_mean_twi);
 
@@ -1002,7 +1002,7 @@ static int hawki_twilight_flat_combine_save(cpl_frameset *framelist,
                            CPL_IO_DEFAULT) != CPL_ERROR_NONE) {
             cpl_msg_error(fctid,"Cannot save product PHU");
             cpl_frame_delete(*product_frame_conf);
-            return(-1);
+            return(CPL_ERROR_UNSPECIFIED);
         }
         cpl_frameset_insert(framelist,*product_frame_conf);
 
@@ -1031,7 +1031,7 @@ static int hawki_twilight_flat_combine_save(cpl_frameset *framelist,
                            CPL_IO_DEFAULT) != CPL_ERROR_NONE) {
             cpl_msg_error(fctid,"Cannot save product PHU");
             cpl_frame_delete(*product_frame_bpm);
-            return(-1);
+            return(CPL_ERROR_UNSPECIFIED);
         }
         cpl_frameset_insert(framelist,*product_frame_bpm);
 
@@ -1062,7 +1062,7 @@ static int hawki_twilight_flat_combine_save(cpl_frameset *framelist,
                                CPL_IO_DEFAULT) != CPL_ERROR_NONE) {
                 cpl_msg_error(fctid,"Cannot save product PHU");
                 cpl_frame_delete(*product_frame_ratioimg);
-                return(-1);
+                return(CPL_ERROR_UNSPECIFIED);
             }
             cpl_frameset_insert(framelist,*product_frame_ratioimg);
         }
@@ -1113,7 +1113,7 @@ static int hawki_twilight_flat_combine_save(cpl_frameset *framelist,
                                CPL_IO_DEFAULT) != CPL_ERROR_NONE) {
                 cpl_msg_error(fctid,"Cannot save product table extension");
                 cpl_propertylist_delete(p);
-                return(-1);
+                return(CPL_ERROR_UNSPECIFIED);
             }
             cpl_propertylist_delete(p);
             cpl_frameset_insert(framelist,*product_frame_ratioimg_stats);
@@ -1176,7 +1176,7 @@ static int hawki_twilight_flat_combine_save(cpl_frameset *framelist,
                        CPL_IO_EXTEND) != CPL_ERROR_NONE) {
         cpl_msg_error(fctid,"Cannot save product image extension");
         cpl_propertylist_delete(p);
-        return(-1);
+        return(CPL_ERROR_UNSPECIFIED);
     }
     cpl_propertylist_delete(p);
 
@@ -1202,7 +1202,7 @@ static int hawki_twilight_flat_combine_save(cpl_frameset *framelist,
                            CPL_IO_EXTEND) != CPL_ERROR_NONE) {
             cpl_propertylist_delete(p);
             cpl_msg_error(fctid,"Cannot save product image extension");
-            return(-1);
+            return(CPL_ERROR_UNSPECIFIED);
         }
         cpl_propertylist_delete(p);
     }
@@ -1223,7 +1223,7 @@ static int hawki_twilight_flat_combine_save(cpl_frameset *framelist,
                            != CPL_ERROR_NONE) {
               cpl_msg_error(fctid,"Cannot save product table extension");
             cpl_propertylist_delete(p);
-             return(-1);
+             return(CPL_ERROR_UNSPECIFIED);
         }        
         cpl_propertylist_delete(p);
     }
@@ -1250,7 +1250,7 @@ static int hawki_twilight_flat_combine_save(cpl_frameset *framelist,
                        CPL_IO_EXTEND) != CPL_ERROR_NONE) {
         cpl_msg_error(fctid,"Cannot save product image extension");
         cpl_propertylist_delete(p);
-        return(-1);
+        return(CPL_ERROR_UNSPECIFIED);
     }
     cpl_propertylist_delete(p);
 
@@ -1271,7 +1271,7 @@ static int hawki_twilight_flat_combine_save(cpl_frameset *framelist,
                        CPL_IO_EXTEND) != CPL_ERROR_NONE) {
         cpl_msg_error(fctid,"Cannot save product image extension");
         cpl_propertylist_delete(p);
-        return(-1);
+        return(CPL_ERROR_UNSPECIFIED);
     }
     cpl_propertylist_delete(p);
 
@@ -1508,7 +1508,7 @@ static int hawki_twilight_flat_combine_lastbit(int jext,
                                               product_frame_bpm);
     if (retval != 0) {
         hawki_twilight_flat_combine_tidy(ps,0);
-        return(-1);
+        return(CPL_ERROR_UNSPECIFIED);
     }
 
     /* Free some stuff up */
